nengo\_spa\.modules
===================

.. automodule:: nengo_spa.modules
   :members:
   :imported-members:

   .. autosummary::

      AssociativeMemory
      BasalGanglia
      Bind
      Compare
      IAAssocMem
      Product
      Scalar
      State
      Thalamus
      ThresholdingAssocMem
      Transcode
      WTAAssocMem
